@@ -4,7 +4,7 @@
 # Module    : sport_flow
 # Created   : July 11, 2013
 #
-# Copyright 2017 ScottFree Analytics LLC
+# Copyright 2020 ScottFree Analytics LLC
 # Mark Conway & Robert D. Scott II
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,10 +45,10 @@ import datetime
 from itertools import groupby
 import logging
 import math
-import multiprocessing as mp
 import numpy as np
 import os
 import pandas as pd
+import sys
 import warnings
 import yaml
 
@@ -155,7 +155,7 @@ def get_sport_config():
 
     full_path = SSEP.join(['.', 'config', 'sport.yml'])
     with open(full_path, 'r') as ymlfile:
-        cfg = yaml.load(ymlfile)
+        cfg = yaml.load(ymlfile, Loader=yaml.FullLoader)
 
     # Store configuration parameters in dictionary
 
@@ -634,6 +634,11 @@ def main(args=None):
 
     """
 
+    # Suppress Warnings
+
+    warnings.simplefilter(action='ignore', category=DeprecationWarning)
+    warnings.simplefilter(action='ignore', category=FutureWarning)
+
     # Logging
 
     logging.basicConfig(format="[%(asctime)s] %(levelname)s\t%(message)s",
@@ -792,8 +797,8 @@ def main(args=None):
             gf['away.score'] = np.random.randint(points_min, points_max, total_games)
         gf['total_points'] = gf['home.score'] + gf['away.score']
 
-        gf['line_delta'] = gf['line'] - gf['line_open']
-        gf['over_under_delta'] = gf['over_under'] - gf['over_under_open']
+        # gf['line_delta'] = gf['line'] - gf['line_open']
+        # gf['over_under_delta'] = gf['over_under'] - gf['over_under_open']
 
         gf = add_features(gf, game_dict, gf.shape[0])
         for index, row in gf.iterrows():
@@ -915,6 +920,4 @@ def main(args=None):
 #
 
 if __name__ == "__main__":
-    warnings.filterwarnings(action='ignore', category=DeprecationWarning)
-    mp.set_start_method('forkserver')
     main()
